SentryAnalyticsService class

Sentry implementation of AnalyticsService.

This service expects Sentry to be pre-initialized by the LittlefishObservabilityManager before initialize is called. It uses the existing Sentry instance via Sentry.clone().

Inheritance
  • Object
  • LittleFishService
  • AnalyticsService<Hub, SentryNavigatorObserver>
  • SentryAnalyticsService

Constructors

SentryAnalyticsService()

Properties

appId String?
getter/setter pairinherited
core ↔ LittleFishCore
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
instance ↔ Hub?
getter/setter pairinherited
instanceId String?
getter/setter pairinherited
isAnalyticsEnabled bool
no setterinherited
isReady bool
no setterinherited
isSetup bool?
no setterinherited
logger → LoggerService
no setterinherited
observer ↔ SentryNavigatorObserver?
getter/setter pairinherited
providerName String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ AnalyticsSettings
getter/setter pairinherited

Methods

enableAnalyticsCollection({required bool enable}) Future<void>
override
getAnalyticsObserver() Future<SentryNavigatorObserver?>
override
getUserConsent() Future<bool>
override
initialize({required AnalyticsSettings settings}) Future<void>
override
logEvent({required AnalyticsEvent e}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultEventParameters({required Map<String, dynamic> parameters}) Future<void>
override
setIsReady({required bool isReady}) Future<void>
inherited
setScreenName({required String name}) Future<void>
override
setUserConsent({bool? adsConsent = false, bool? adsStorageConsent = false, bool? analyticsConsent = false, bool? analyticsStorageConsent = false, bool? adsUserDataConsent = false, bool? personalisationStorageConsentGranted = false, bool? securityStorageConsentGranted = false, bool? functionalityConsent = false}) Future<void>
override
setUserId({required String userId}) Future<void>
override
setUserProperties({required Map<String, String> properties}) Future<void>
override
setUserProperty({required String name, required String value}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited